@@ -5,23 +5,14 @@
 udocker unit tests: UdockerCLI
 """
 
-import os
-import sys
-
-new_path = []
-new_path.append(os.path.dirname(os.path.realpath(__file__)) + "/../..")
-new_path.append(os.path.dirname(os.path.realpath(__file__)) + "/../../udocker")
-new_path.extend(sys.path)
-sys.path = new_path
-
 from unittest import TestCase, main
 from unittest.mock import Mock, patch
 from udocker.config import Config
 from udocker.cmdparser import CmdParser
 from udocker.cli import UdockerCLI
 import collections
-collections.Callable = collections.abc.Callable
 
+collections.Callable = collections.abc.Callable
 BUILTIN = "builtins"
 BOPEN = BUILTIN + '.open'
 
