@@ -3,21 +3,13 @@
 udocker unit tests: DockerIoAPI
 """
 
-import os
-import sys
-
-new_path = []
-new_path.append(os.path.dirname(os.path.realpath(__file__)) + "/../..")
-new_path.append(os.path.dirname(os.path.realpath(__file__)) + "/../../udocker")
-new_path.extend(sys.path)
-sys.path = new_path
-
 from unittest import TestCase, main
 from unittest.mock import patch, Mock
 from io import BytesIO as strio
 from udocker.docker import DockerIoAPI
-from config import Config
+from udocker.config import Config
 import collections
+
 collections.Callable = collections.abc.Callable
 
 
